pyphasefield.Engines package
============================

Submodules
----------

pyphasefield.Engines.AnisoDorrGPU module
----------------------------------------

.. automodule:: pyphasefield.Engines.AnisoDorrGPU
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.CahnAllen module
-------------------------------------

.. automodule:: pyphasefield.Engines.CahnAllen
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.CahnHilliard module
----------------------------------------

.. automodule:: pyphasefield.Engines.CahnHilliard
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.Diffusion module
-------------------------------------

.. automodule:: pyphasefield.Engines.Diffusion
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.DiffusionGPU module
----------------------------------------

.. automodule:: pyphasefield.Engines.DiffusionGPU
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.NCGPU module
---------------------------------

.. automodule:: pyphasefield.Engines.NCGPU
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.NCGPU\_new module
--------------------------------------

.. automodule:: pyphasefield.Engines.NCGPU_new
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.NComponent module
--------------------------------------

.. automodule:: pyphasefield.Engines.NComponent
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.Template module
------------------------------------

.. automodule:: pyphasefield.Engines.Template
   :members:
   :undoc-members:
   :show-inheritance:

pyphasefield.Engines.Warren1995 module
--------------------------------------

.. automodule:: pyphasefield.Engines.Warren1995
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyphasefield.Engines
   :members:
   :undoc-members:
   :show-inheritance:
